package
Version:
v0.0.0-...-3facaca
Opens a new window with list of versions in this module.
Published: Oct 29, 2020
License: CC0-1.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Areaer interface {
Area() int
}
type Rectangle struct {
Width int
Height int
}
type Square struct {
Size int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.